log using "Arceneaux QJPS repl.log", replace

************************************************************************************
*                        New Mexico Primary Experiment                             *
************************************************************************************

set mem 100m
set more off

*****Table 1
use full_individual_level.dta, clear
tab treat_canvass phone_treat2, missing 
	/*treat_canvass: 0=control group, 1=candidate treatment, 2=field treatment, .=not assigned*/
	/*phone_treat2: 0=control group, 1=phone treatment, .=not assigned*/
use full_precinct_level.dta, clear
tab canvass_treat, missing
	/*canvass_treat: 0=control group, 1=candidate treatment, 2=field treatment, .=not assigned*/


**********Randomization Check****************************************
**DK experiment
*Full Sample
use full_precinct_level.dta, clear
tabstat  v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize, by(canvass_treat) stat(mean sem)
tab canvass_treat /*Number of Observations*/
reg  treat_cand v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize   strata_c strata_f strata_cw strata_fw 
reg  treat_fld v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize   strata_c strata_f strata_cw strata_fw
*Survey Sample
use survey_precinct_level.dta, clear
tabstat  v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize, by(canvass_treat) stat(mean sem)
tab canvass_treat /*Number of Observations*/
reg  treat_cand v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize   strata_c strata_f strata_cw strata_fw 
reg  treat_fld v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize   strata_c strata_f strata_cw strata_fw

**Phone experiment
***IMPORTANT: TO CONDUCT INCREMENTAL F-TEST, SAVE iftest.ado IN APPROPRIATE STATA ADO DIRECTORY***
*Full Sample
use full_individual_level.dta, clear
tabstat  v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize, by(phone_treat2) stat(mean sem)
tab  phone_treat2 phone_contact, row /*Contact Rate*/
tab treat_cand  cand_dk, row         /*Contact Rate for candidate*/
tab treat_fld    fdk_ctact_any, row  /*Contact Rate for field*/
tab phone_treat2 /*Number of Observations*/
iftest, base(reg phone_treat2 hhsize) full(reg  phone_treat2 hhsize v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age)
*Survey Sample
use survey_individual_level.dta, clear
tabstat  v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age hhsize, by(phone_treat2) stat(mean sem)
tab  phone_treat2 phone_contact, row /*Contact Rate for phone*/
tab treat_cand  cand_dk, row         /*Contact Rate for candidate*/
tab treat_fld    fdk_ctact_any, row  /*Contact Rate for field*/
tab phone_treat2 /*Number of Observations*/
iftest, base(reg phone_treat2 hhsize) full(reg  phone_treat2 hhsize v92p v92g v94p v94g v96p v96g v98p v98g v00p v00g v02p v02g female newreg age)

***************Models**************************************************
use survey_individual_level.dta, clear

********Main Analysis********
**Vote Preference
*ITT
reg votepref treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct)  
reg votepref phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)     
*ATT
ivreg votepref (cand_dk fdk_ctact_any female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw) [pw=weight], cluster(precinct)  
ivreg votepref (phone_contact female newreg age hhsize v02p=phone_treat2 female newreg age hhsize v02p), cluster(phn_cluster)    

**Vote Preference + Mobilization 
/*Includes all obs since mlogit is required to estimate*/
/*Thus, only possible to estimate ITT*/
mlogit  votepref_mobilize_DKsep treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct) b(0)
mlogit  votepref_mobilize_DKsep treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw  [pw=weight], cluster(precinct) b(-1)
mlogit  votepref_mobilize_DKsep phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)    b(0)
mlogit  votepref_mobilize_DKsep phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)    b(-1)

**Hypodermic Stimulius (RFs and DKs coded as 0)
*ITT
reg issue treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct)  
reg issue phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)   
reg slogan treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct)  
reg slogan phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)    
*ATT
ivreg issue (cand_dk fdk_ctact_any female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct)  
ivreg issue (phone_contact female newreg age hhsize v02p=phone_treat2 female newreg age hhsize v02p), cluster(phn_cluster)   
ivreg slogan (cand_dk fdk_ctact_any female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct)  
ivreg slogan (phone_contact female newreg age hhsize v02p=phone_treat2 female newreg age hhsize v02p), cluster(phn_cluster)   


**Priming
*ITT
reg votepref treat_cand treat_fld issue slogan  issueXtreat_cand issueXtreat_fld sloganXtreat_cand sloganXtreat_fld female- hhsize v02p v94p v94g v96p strata_c- strata_fw [pw=weight], cluster(precinct)  
reg votepref phone_treat2 issue slogan issueXphone_treat2 sloganXphone_treat2 female- hhsize v02p, cluster(phn_cluster)   
*ATT  
ivreg votepref (cand_dk fdk_ctact_any issue slogan  issueXcand_dk issueXfld_dk  sloganXcand_dk sloganXfld_dk female- hhsize v02p v94p v94g v96p strata_c- strata_fw ///
=treat_cand treat_fld issue slogan  issueXtreat_cand issueXtreat_fld sloganXtreat_cand sloganXtreat_fld female- hhsize v02p v94p v94g v96p strata_c- strata_fw) [pw=weight], cluster(precinct)    
ivreg votepref (phone_contact issue slogan issueXphone_contact sloganXphone_contact female- hhsize v02p=phone_treat2 issue slogan issueXphone_treat2 sloganXphone_treat2 female- hhsize v02p), cluster(phn_cluster)  


**Opinionation (RFs removed)
*ITT
reg  issue_op  treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) 
reg  issue_op  phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)    
reg  slogan_op treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct)  
reg  slogan_op phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)     
*ATT
ivreg  issue_op  (cand_dk fdk_ctact_any female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct) 
ivreg  issue_op  (phone_contact female newreg age hhsize v02p=phone_treat2 female newreg age hhsize v02p), cluster(phn_cluster)   
ivreg  slogan_op  (cand_dk fdk_ctact_any female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct) 
ivreg  slogan_op  (phone_contact female newreg age hhsize v02p=phone_treat2 female newreg age hhsize v02p), cluster(phn_cluster)   


********All Observations******
**Vote Preference
mlogit  votepref_DKsep treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct) b(0)
mlogit  votepref_DKsep phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)    b(0)

**Vote Preference + Mobilization
/*Estimated in last section*/

**Hypodermic Stimulius 
/*Estimated in last section*/ 

**Priming
/*Model won't estimate properly b/c of small N in cells for interaction terms*/

**Opinionation (RFs separated)
mlogit  issue_op_RFsep treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) b(0)
mlogit  issue_op_RFsep phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)   b(0) 
mlogit  slogan_op_RFsep treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) b(0)
mlogit  slogan_op_RFsep phone_treat2 female newreg age hhsize v02p, cluster(phn_cluster)   b(0)  


*******Canvassing and Phone Expts estimated together*******
**Vote Preference
*RF/DKs Removed
reg votepref treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct)  
ivreg votepref (cand_dk fdk_ctact_any phone_contact female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw) [pw=weight], cluster(precinct)  
*All obs
mlogit  votepref_DKsep treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct) b(0)

**Vote Preference + Mobilization
*All obs
mlogit  votepref_mobilize_DKsep treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct) b(0)
mlogit  votepref_mobilize_DKsep treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw  [pw=weight], cluster(precinct) b(-1)

**Hypodermic Stimulius
*RF/DKs coded as 0 (All obs)
reg issue treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct)  
reg slogan treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct)  
ivreg issue (cand_dk fdk_ctact_any phone_contact female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct)  
ivreg slogan (cand_dk fdk_ctact_any phone_contact female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct)  


**Priming
*RF/DKs Removed
reg votepref treat_cand treat_fld phone_treat2 issue slogan issueXtreat_cand issueXtreat_fld issueXphone_treat2 sloganXtreat_cand sloganXtreat_fld sloganXphone_treat2 female- hhsize v02p v94p v94g v96p strata_c- strata_fw [pw=weight], cluster(precinct)  
ivreg votepref (cand_dk fdk_ctact_any phone_contact issue slogan  issueXcand_dk issueXfld_dk issueXphone_contact sloganXcand_dk sloganXfld_dk sloganXphone_contact female- hhsize v02p v94p v94g v96p strata_c- strata_fw ///
=treat_cand treat_fld phone_treat2 issue slogan  issueXtreat_cand issueXtreat_fld sloganXtreat_cand sloganXtreat_fld issueXphone_treat2 sloganXphone_treat2 female- hhsize v02p v94p v94g v96p strata_c- strata_fw) [pw=weight], cluster(precinct)    
*All obs
/*Model won't estimate properly b/c of small N in cells for interaction terms*/

**Opinionation
*RFs removed
reg  issue_op  treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) 
reg  slogan_op treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) 
ivreg  issue_op  (cand_dk fdk_ctact_any phone_contact female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct) 
ivreg  slogan_op  (cand_dk fdk_ctact_any phone_contact female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw ///
=treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw)   [pw=weight], cluster(precinct) 
*All obs
mlogit  issue_op_RFsep treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) b(0)
mlogit  slogan_op_RFsep treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw   [pw=weight], cluster(precinct) b(0)

**Campaign Interest
ologit campvol treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct)  
ologit campvol phone_treat2 female newreg age hhsize v02p,  cluster(phn_cluster) 

ologit campvol_DKRFsep treat_cand treat_fld female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct)  
ologit campvol_DKRFsep phone_treat2 female newreg age hhsize v02p,   cluster(phn_cluster)

ologit campvol treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct)  
ologit campvol_DKRFsep treat_cand treat_fld phone_treat2 female newreg age hhsize v02p v94p v94g v96p strata_c strata_f strata_cw strata_fw [pw=weight], cluster(precinct)  


log close


